==> activity-center-api-3.2.0-CLOUD-DEV-20231229.084543-49-sources.jar: com/tydic/dyc/act/service/bo/DycActActivityBaseInfoBO.java <==
package com.tydic.dyc.act.service.bo;

import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;

/**
 * 标题：DycActActivityBaseInfoBO
 * 说明：
 * 时间： 2023-12-12 11:23
 * 作者 @author LY
 */
@Data
public class DycActActivityBaseInfoBO implements Serializable {
    private static final long serialVersionUID = 272538515635759538L;

    /**
     * 活动id
     */
    private Long activityId;
    /**
     * 活动版本号
     */
    private Integer activityVersion;
    /**
     * 活动编号
     */
    private String activityCode;
    /**
     * 活动适用组织id
     */
    private Long activityScopeOrgId;
    /**
     * 活动适用组织名称
     */
    private String activityScopeOrgName;
    /**
     * 活动名称
     */
    private String activityName;
    /**
     * 活动类型:1:工会活动；2：劳防活动
     */
    private Integer activityType;
    /**
     * 活动期限:1:有限期，2:无限期
     */
    private Integer activityCycleType;
    /**
     * 活动开始时间
     */
    private Date activityStartTime;
    /**
     * 活动结束时间
     */
    private Date activityEndTime;
    /**
     * 活动状态:1:草稿；2：待审批；3：已驳回；4：启用；5：已生效；6：停用；7：已失效；8：变更中
     */
    private String activityState;
    /**
     * 创建时间
     */
    private Date createTime;
    /**
     * 创建人ID
     */
    private Long createUserId;
    /**
     * 创建人名称
     */
    private String createUserName;
    /**
     * 更新时间
     */
    private Date updateTime;
    /**
     * 更新人名称
     */
    private String updateUserName;
    /**
     * 更新人ID
     */
    private Long updateUserId;
    /**
     * 创建人机构ID
     */
    private Long createOrgId;
    /**
     * 创建人机构名称
     */
    private String createOrgName;
    /**
     * 创建人机构路径
     */
    private String createOrgTreePath;
    /**
     * 创建人公司ID
     */
    private Long createCompanyId;
    /**
     * 创建人公司名称
     */
    private String createCompanyName;
    /**
     * 活动类型翻译
     */
    private String activityTypeStr;
    /**
     * 活动状态翻译
     */
    private String activityStateStr;
    /**
     * 活动期限类型翻译
     */
    private String activityCycleTypeStr;
}

==> activity-center-api-3.2.1-CLOUD-DEV-20240511.071315-206-sources.jar: com/tydic/dyc/act/service/bo/DycActActivityBaseInfoBO.java <==
package com.tydic.dyc.act.service.bo;

import lombok.Data;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 标题：DycActActivityBaseInfoBO
 * 说明：
 * 时间： 2023-12-12 11:23
 * 作者 @author LY
 */
@Data
public class DycActActivityBaseInfoBO implements Serializable {
    private static final long serialVersionUID = 272538515635759538L;

    /**
     * 活动id
     */
    private Long activityId;
    /**
     * 活动版本号
     */
    private Integer activityVersion;
    /**
     * 活动编号
     */
    private String activityCode;
    /**
     * 活动适用组织id
     */
    private Long activityScopeOrgId;
    /**
     * 活动适用组织名称
     */
    private String activityScopeOrgName;
    /**
     * 活动名称
     */
    private String activityName;
    /**
     * 活动场景id
     */
    private Long activitySceneId;
    /**
     * 活动场景名称
     */
    private String activitySceneName;
    /**
     * 活动类型:1:工会活动；2：劳防活动
     */
    private Integer activityType;
    /**
     * 活动期限:1:有限期，2:无限期
     */
    private Integer activityCycleType;
    /**
     * 活动开始时间
     */
    private Date activityStartTime;
    /**
     * 活动结束时间
     */
    private Date activityEndTime;
    /**
     * 活动状态:1:草稿；2：待审批；3：已驳回；4：启用；5：已生效；6：停用；7：已失效；8：变更中
     */
    private String activityState;
    /**
     * 用户总数
     */
    private Integer totalUser;
    /**
     * 积分总数
     */
    private BigDecimal totalScores;
    /**
     * 商品总数
     */
    private Integer totalCommodity;
    /**
     * 类目总数
     */
    private Integer totalCatalog;
    /**
     * 活动同步状态:
     1:待同步
     2：同步中
     3：同步成功
     4：同步失败
     */
    private Integer activitySyncState;

    private String activitySyncStateStr;
    /**
     * 创建时间
     */
    private Date createTime;
    /**
     * 创建人ID
     */
    private Long createUserId;
    /**
     * 创建人名称
     */
    private String createUserName;
    /**
     * 更新时间
     */
    private Date updateTime;
    /**
     * 更新人名称
     */
    private String updateUserName;
    /**
     * 更新人ID
     */
    private Long updateUserId;
    /**
     * 创建人机构ID
     */
    private Long createOrgId;
    /**
     * 创建人机构名称
     */
    private String createOrgName;
    /**
     * 创建人机构路径
     */
    private String createOrgTreePath;
    /**
     * 创建人公司ID
     */
    private Long createCompanyId;
    /**
     * 创建人公司名称
     */
    private String createCompanyName;
    /**
     * 活动类型翻译
     */
    private String activityTypeStr;
    /**
     * 活动状态翻译
     */
    private String activityStateStr;
    /**
     * 活动期限类型翻译
     */
    private String activityCycleTypeStr;
    /**
     * 活动开始到结束时间
     */
    private String activityStartToEndTime;
    /**
     * 最后付款日期
     */
    private Date lastPayTime;
    /**
     * 最后付款日期运营
     */
    private Date yyLastPayTime;
    /**
     * 最后付款日期
     */
    private String lastPayTimeStr;
    /**
     * 最后付款日期运营
     */
    private String yyLastPayTimeStr;
    /**
     * 商品关联方式:1:商品池；2：商品类型；3：商品
     */
    private Integer commodityRelaMethod;
    /**
     * 商品关联方式翻译
     */
    private String commodityRelaMethodStr;
    /**
     * 是否有订单记录：
     *
     * true：有
     *
     * false：没有
     */
    private Boolean orderFalg;
    /**
     * 是否有变更记录：
     *
     * true：有
     *
     * false：没有
     */
    private Boolean changeFalg;
    /**
     * 是否有积分记录：
     *
     * true：有
     *
     * false：没有
     */
    private Boolean scores;
    private List<DycActActivitySupplierInfoBO> activitySupplierList;
    /**
     * 供应商名称
     */
    private String supplierName;
    /**
     * 外部活动ID
     */
    private String extActivityId;

    /**
     * 预警类型
     */
    private Integer alertType;
    /**
     * 是否结算:
     * 0:未结算；
     * 1：已结算
     */
    private Integer isSettleFlag;
}
